@@ -76,10 +76,11 @@ import LaueTools.matchingrate as matchingrate
 from LaueTools.GUI.AutoindexationGUI import DistanceScreeningIndexationBoard
 from LaueTools.GUI.B0matrixLatticeEditor import B0MatrixEditor
 from LaueTools.GUI.ResultsIndexationGUI import RecognitionResultCheckBox
-from LaueTools.GUI.OpenSpotsListFileGUI import (askUserForFilename, OnOpenPeakList, Launch_DetectorParamBoard,
+from LaueTools.GUI.OpenSpotsListFileGUI import (askUserForFilename, OpenPeakList, Launch_DetectorParamBoard,
                                                 OpenCorfile, SetGeneralLaueGeometry)
 from LaueTools.GUI.ManualIndexFrame import ManualIndexFrame
 from LaueTools.GUI.MatrixEditor import MatrixEditor_Dialog
+import LaueTools.GUI.OpenSpotsListFileGUI as OSLFGUI
 
 LaueToolsProjectFolder = os.path.split(os.path.split(os.path.abspath(__file__))[0])[0]
 
@@ -130,8 +131,13 @@ class LaueToolsGUImainframe(wx.Frame):
 
         self.filename = filename
         self.dirname = projectfolder
+        self.filenamepklist = filename
+        self.dirnamepklist = projectfolder
+        self.imgfilename = None
+        self.imgdirname = projectfolder
         #print("self.dirname", self.dirname)
         self.writefolder = None
+        self.resetwf = False
         self.consolefile = consolefile
 
         # --- begin of general layout -------------------
@@ -381,26 +387,15 @@ class LaueToolsGUImainframe(wx.Frame):
         ask user to select folder and image file
         and launch the peak search board(class PeakSearchFrame)
         """
-        if askUserForFilename(self, style=wx.OPEN, **self.defaultFileDialogOptionsImage()):
+        if askUserForFilename(self, filetype = 'image', style=wx.OPEN, **self.defaultFileDialogOptionsImage()):
 
-            os.chdir(self.dirname)
-            #print("self.dirname", self.dirname)
-            print(os.curdir)
-
-            self.DataPlot_filename = str(self.filename)
-            #print("Current file   :", self.DataPlot_filename)
-
-            nbparts = len(self.DataPlot_filename.split("."))
+            nbparts = len(self.imgfilename.split("."))
             if nbparts == 2:
-                prefix, file_extension = self.DataPlot_filename.rsplit(".", 1)
+                _, file_extension = self.imgfilename.rsplit(".", 1)
             elif nbparts == 3:
-                prefix, ext1, ext2 = self.DataPlot_filename.rsplit(".", 2)
+                _, ext1, ext2 = self.imgfilename.rsplit(".", 2)
                 file_extension = ext1 + "." + ext2
 
-            #print("prefix", prefix)
-
-            #print("extension", file_extension)
-
             if file_extension in list_CCD_file_extensions:
 
                 detectedCCDlabel = autoDetectDetectorType(file_extension)
@@ -412,8 +407,8 @@ class LaueToolsGUImainframe(wx.Frame):
 
                 initialParameter = {}
                 initialParameter["title"] = "peaksearch Board"
-                initialParameter["imagefilename"] = self.filename
-                initialParameter["dirname"] = self.dirname
+                initialParameter["imagefilename"] = self.imgfilename
+                initialParameter["dirname"] = self.imgdirname
                 initialParameter["mapsLUT"] = "OrRd"
                 initialParameter["CCDLabel"] = self.CCDLabel
                 initialParameter["writefolder"] = self.writefolder
@@ -426,21 +421,20 @@ class LaueToolsGUImainframe(wx.Frame):
                     initialParameter["stackimageindex"] = 0
                     initialParameter["Nbstackedimages"] = 20
 
-                peakserchframe = MainPeakSearchFrame(self, -1, initialParameter,
+                peaksearchframe = MainPeakSearchFrame(self, -1, initialParameter,
                                                                         "peaksearch Board")
-                peakserchframe.Show(True)
+                peaksearchframe.Show(True)
 
-    #                    self.DataPlot_filename = ploimage.peaks_filename
 
     def OnOpenPeakList(self, _):
         """ Open peak list either .dat or .cor file and initinalize peak list
         for further use (indexation)
         """
         # read peak list and detector calibration parameters
-        OnOpenPeakList(self)
+        OpenPeakList(self)
 
         # ---------------------------------------------
-        self.filename = self.DataPlot_filename
+        self.filenamepklist = self.DataPlot_filename
 
         self.set_gnomonic_data()
         # ---------------------------------------------
@@ -499,7 +493,7 @@ class LaueToolsGUImainframe(wx.Frame):
 
         prefix, file_extension = self.DataPlot_filename.rsplit(".", 1)
 
-        os.chdir(self.dirname)
+        #os.chdir(self.dirname)
 
         fullpathfile = os.path.join(self.dirname, self.DataPlot_filename)
 
@@ -581,7 +575,7 @@ class LaueToolsGUImainframe(wx.Frame):
         """
         call the board to define destination folder to  write files
         """
-        PB = PreferencesBoard(self, -1, "Folder Preferences Board")
+        PB = PreferencesBoard(self, -1, "Writing Results Folder Preferences Board")
         PB.ShowModal()
         PB.Destroy()
 
@@ -618,7 +612,8 @@ class LaueToolsGUImainframe(wx.Frame):
             return
 
         #print("AllDataToIndex in dict: ", "AllDataToIndex" in self.indexation_parameters)
-
+        self.indexation_parameters["writefolder"] = self.writefolder
+        self.indexation_parameters["dirname"] = self.dirname
         self.indexation_parameters["kf_direction"] = self.kf_direction
         self.indexation_parameters["DataPlot_filename"] = self.DataPlot_filename
         self.indexation_parameters["dict_Materials"] = self.dict_Materials
@@ -741,7 +736,8 @@ class LaueToolsGUImainframe(wx.Frame):
         #         self.indexation_parameters['AllDataToIndex'] is already set
         #         self.indexation_parameters ={}
         #print("AllDataToIndex in dict: ", "AllDataToIndex" in self.indexation_parameters)
-
+        self.indexation_parameters["writefolder"] = self.writefolder
+        self.indexation_parameters["dirname"] = self.dirname
         self.indexation_parameters["kf_direction"] = self.kf_direction
         self.indexation_parameters["DataPlot_filename"] = self.DataPlot_filename
         self.indexation_parameters["dict_Materials"] = self.dict_Materials
@@ -834,7 +830,8 @@ class LaueToolsGUImainframe(wx.Frame):
             return
 
         #print("AllDataToIndex in dict: ", "AllDataToIndex" in self.indexation_parameters)
-
+        self.indexation_parameters["writefolder"] = self.writefolder
+        self.indexation_parameters["dirname"] = self.dirname
         self.indexation_parameters["kf_direction"] = self.kf_direction
         self.indexation_parameters["DataPlot_filename"] = self.DataPlot_filename
         self.indexation_parameters["dict_Materials"] = self.dict_Materials
@@ -921,7 +918,8 @@ class LaueToolsGUImainframe(wx.Frame):
             return
 
         print("AllDataToIndex in dict: ", "AllDataToIndex" in self.indexation_parameters)
-
+        self.indexation_parameters["writefolder"] = self.writefolder
+        self.indexation_parameters["dirname"] = self.dirname
         self.indexation_parameters["kf_direction"] = self.kf_direction
         self.indexation_parameters["DataPlot_filename"] = self.DataPlot_filename
         self.indexation_parameters["dict_Materials"] = self.dict_Materials
@@ -1016,7 +1014,8 @@ class LaueToolsGUImainframe(wx.Frame):
         #         self.indexation_parameters['AllDataToIndex'] is already set
         #         self.indexation_parameters ={}
         print("AllDataToIndex in dict: ", "AllDataToIndex" in self.indexation_parameters)
-
+        self.indexation_parameters["writefolder"] = self.writefolder
+        self.indexation_parameters["dirname"] = self.dirname
         self.indexation_parameters["kf_direction"] = self.kf_direction
         self.indexation_parameters["DataPlot_filename"] = self.DataPlot_filename
         self.indexation_parameters["dict_Materials"] = self.dict_Materials
@@ -1076,7 +1075,7 @@ class LaueToolsGUImainframe(wx.Frame):
         """
         Method launching Calibration Board
         """
-        starting_param = [100, 1000, 1000, 0, 0]
+        starting_param = [77, 1000, 1000, 0, 0]
 
         print("Starting param", starting_param)
 
@@ -1507,11 +1506,16 @@ class LaueToolsGUImainframe(wx.Frame):
         DEFAULTFILE = "defaultGe0001.cor"
         defaultdatafile = os.path.join(LaueToolsProjectFolder, "Examples", "Ge", DEFAULTFILE)
 
-        print("self.detectordiameter in OpenDefaultData()", self.detectordiameter)
+        #print("self.detectordiameter in OpenDefaultData()", self.detectordiameter)
 
-        self.dirname = os.path.split(os.path.abspath(defaultdatafile))[0]
-        print('self.dirname', self.dirname)
-        os.chdir(self.dirname)
+        self.dirnamepklist = os.path.split(os.path.abspath(defaultdatafile))[0]
+        print('self.dirnamepklist', self.dirnamepklist)
+        self.filenamepklist = DEFAULTFILE
+        print('self.filenamepklist', self.filenamepklist)
+        if os.access(defaultdatafile, os.W_OK):
+            self.writefolder = self.dirnamepklist
+        else:
+            self.writefolder = OSLFGUI.askUserForDirname(self)
 
         self.DataPlot_filename = DEFAULTFILE
 
@@ -1520,7 +1524,7 @@ class LaueToolsGUImainframe(wx.Frame):
         self.set_gnomonic_data()
 
         # ---------------------------------------------
-        self.filename = self.DataPlot_filename
+        self.filenamepklist = self.DataPlot_filename
         self.init_DataSet()
 
         # create DB spots(dictionary)
@@ -1538,7 +1542,8 @@ class LaueToolsGUImainframe(wx.Frame):
         # DataSetObject init
         self.DataSet = spotsset()
         # get spots scattering angles,X,Y positions from .cor file
-        warningflag = self.DataSet.importdatafromfile(self.filename)
+        fullpath = os.path.join(self.dirnamepklist, self.filenamepklist)
+        warningflag = self.DataSet.importdatafromfile(fullpath)
         if warningflag:
             wx.MessageBox(warningflag + 'Please set an other Laue geometry if needed from the menu!', 'Info')
         self.DataSet.pixelsize = self.pixelsize
@@ -1550,7 +1555,7 @@ class LaueToolsGUImainframe(wx.Frame):
         """display spots list prpos in main LaueToolsGUI window
         """
         # -----------------------------------------------
-        textfile = open(os.path.join(self.dirname, self.DataPlot_filename), "r")
+        textfile = open(os.path.join(self.dirnamepklist, self.filenamepklist), "r")
         String_in_File_Data = textfile.read()
         self.control.SetValue(String_in_File_Data)
         textfile.close()
@@ -1883,41 +1888,67 @@ class PreferencesBoard(wx.Dialog):
     """
     def __init__(self, parent, _id, title):
 
-        wx.Dialog.__init__(self, parent, _id, title, size=(600, 200))
+        wx.Dialog.__init__(self, parent, _id, title, size=(700, 350))
 
         panel = wx.Panel(self, -1, style=wx.SIMPLE_BORDER, size=(590, 190), pos=(5, 5))
 
         self.parent = parent
-
+        self.dirname = os.path.abspath(parent.dirname)
         self.writefolder = None
         # widgets ----------
-        self.samefolder = wx.RadioButton(panel, -1, "Images folder", (25, 15))
-        self.userdefinedrelfolder = wx.RadioButton(panel, -1, "path relative to lauetools", (25, 55))
-        self.userdefinedabsfolder = wx.RadioButton(panel, -1, "absolute path", (25, 95))
+        wf = parent.writefolder
+        if parent.writefolder is None:
+            wf = 'None'
+        wx.StaticText(panel,-1, "Current writing folder: %s"%wf, (25, 15))
+        wx.StaticText(panel,-1, "Set results folder to:", (25, 55))
+        self.samefolder = wx.RadioButton(panel, -1, "same folder as images or peaks lists when loading them (Be careful of write access!)", (25, 95))
+        self.askfolder = wx.RadioButton(panel, -1, "user selected folder when loading a new image or peak list", (25, 135))
+        self.userdefinedrelfolder = wx.RadioButton(panel, -1, "path relative to lauetools", (25, 175))
+        self.userdefinedabsfolder = wx.RadioButton(panel, -1, "absolute path", (25, 215))
         self.samefolder.SetValue(True)
 
-        self.relativepathname = wx.TextCtrl(panel, -1, "./analysis", (250, 50), (340, -1))
-        self.abspathname = wx.TextCtrl(panel, -1, "/myhome/myfolder", (250, 90), (340, -1))
+        self.relativepathname = wx.TextCtrl(panel, -1, "./analysis", (250, 170), (340, -1))
+        self.abspathname = wx.TextCtrl(panel, -1, self.dirname, (250, 210), (340, -1))
+        self.browsebtn = wx.Button(panel, -1,'...', (600, 210), (60, -1))
 
-        wx.Button(panel, 1, "Accept", (15, 150), (90, 40))
+        self.browsebtn.Bind(wx.EVT_BUTTON, self.onBrowseFolder)
+
+        wx.Button(panel, 1, "Accept", (15, 250), (90, 40))
         self.Bind(wx.EVT_BUTTON, self.OnAccept, id=1)
 
-        wx.Button(panel, 2, "Quit", (150, 150), (90, 40))
+        wx.Button(panel, 2, "Quit", (150, 250), (90, 40))
         self.Bind(wx.EVT_BUTTON, self.OnQuit, id=2)
 
+    def onBrowseFolder(self, _):
+        folder = OSLFGUI.askUserForDirname(self)
+        self.abspathname.SetValue(str(folder))
+
     def OnAccept(self, _):
         """ accept and set parent folders correspondingly and quit """
+        resetwf = False
         if self.samefolder.GetValue():
             self.writefolder = "."
+        elif self.askfolder.GetValue():
+            self.writefolder = None
+            resetwf = True
         elif self.userdefinedrelfolder.GetValue():
             self.writefolder = os.path.join(LAUETOOLSFOLDER,
                                             str(self.relativepathname.GetValue())[2:])
         elif self.userdefinedabsfolder.GetValue():
             self.writefolder = str(self.abspathname.GetValue())
 
-        self.parent.writefolder = self.writefolder
-
-        self.Close()
+        if self.writefolder is not None:
+            abspath = os.path.abspath(self.writefolder)
+            if not os.access(abspath, os.W_OK):
+                wx.MessageBox('Not writable folder: %s'%abspath,'Error')
+            else:
+                self.parent.writefolder = self.writefolder
+                self.resetwf = resetwf
+                self.Close()
+        else:
+            self.parent.writefolder = self.writefolder
+            self.resetwf = resetwf
+            self.Close()
 
     def OnQuit(self, _):
         """ quit """
