@@ -519,16 +519,20 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
 
     USE_RAW_METHOD = False
 
-    if verbose > 1: print("CCDLabel in readCCDimage", CCDLabel)
+    if verbose > 1:
+        print("CCDLabel in readCCDimage", CCDLabel)
+        print('FABIO_EXISTS',FABIO_EXISTS)
+        print('LIBTIFF_EXISTS',LIBTIFF_EXISTS)
+        print('PIL_EXISTS',PIL_EXISTS)
     #    if extension != extension:
     #        print "warning : file extension does not match CCD type set in Set CCD File Parameters"
     if FABIO_EXISTS:
-
         if CCDLabel in ('MARCCD165', "EDF", "EIGER_4M", "EIGER_1M",
                         "sCMOS", "sCMOS_fliplr", "sCMOS_fliplr_16M", "sCMOS_16M",
                         "Rayonix MX170-HS", 'psl_weiwei', 'ImageStar_dia_2021'):
 
-            if verbose > 1: print('----> Using fabio ... to open %s\n'%filename)
+            if verbose > 1:
+                print('----> Using fabio ... to open %s\n'%filename)
             # warning import Image  # for well read of header only
 
             if dirname is not None:
@@ -573,7 +577,7 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
         if verbose > 1:
             print("----> Using libtiff...")
         if CCDLabel in ("sCMOS", "MARCCD165", "TIFF Format", "FRELONID15_corrected", "VHR_PSI",
-                            "VHR_DLS", "MARCCD225", "Andrea", "pnCCD_Tuba"):
+                            "VHR_DLS", "MARCCD225", "Andrea", "pnCCD_Tuba", "sCMOS_16M"):
 
             #         print "tiff format", CCDLabel
             #             print "dirname, filename", dirname, filename
@@ -591,8 +595,9 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
             USE_RAW_METHOD = True
 
     elif PIL_EXISTS:
-        if verbose > 1:print("using PIL's module Image")
-        if CCDLabel in ("sCMOS", "MARCCD165"):
+        if verbose > 1:
+            print("using PIL's module Image")
+        if CCDLabel in ("sCMOS", "MARCCD165", "sCMOS_16M"):
             if verbose > 1: print('PIL is too slow. Better install libtiff or fabio. Meanwhile ...')
             USE_RAW_METHOD = True
         elif CCDLabel in ("VHR_PSI", "VHR_DLS", "MARCCD225", "Andrea", "pnCCD_Tuba"):
@@ -625,7 +630,7 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
             if CCDLabel in ("ImageStar_1528x1528",):
                 nbpixels = 1528
             offsetheader = filesize - nbpixels * nbpixels * bytes_per_pixels
-        
+
         elif CCDLabel == "ImageStar_dia_2021":
             filesize=getfilesize(dirname, filename)
             bytes_per_pixels = 2
@@ -635,7 +640,7 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
         elif CCDLabel in ("sCMOS",):
             if verbose > 0: print("for sCMOS not using libtiff, raw method ...")
             # offsetheader may change ...
-            filesize=getfilesize(dirname, filename)
+            filesize = getfilesize(dirname, filename)
             offsetheader = filesize - 2016*2018 * 2
 
         dataimage = readoneimage(filename,
@@ -644,7 +649,7 @@ def readCCDimage(filename, CCDLabel="MARCCD165", dirname=None, stackimageindex=-
                                 offset=offsetheader,
                                 formatdata=formatdata)
 
-        print("dataimage",dataimage)
+        print("dataimage", dataimage)
 
         if CCDLabel in ("FRELONID15_corrected",):
 
